@@ -50,7 +50,7 @@ $lang = array_merge($lang, array(
 	'ACP_BAN'					=> 'Bandeig',
 	'ACP_BAN_EMAILS'			=> 'Bandeig d’adreces electròniques',
 	'ACP_BAN_IPS'				=> 'Bandeig d’adreces IP',
-	'ACP_BAN_USERNAMES'			=> 'Bandeig de noms d’usuari',
+	'ACP_BAN_USERNAMES'			=> 'Bandeig d’usuaris',
 	'ACP_BBCODES'				=> 'BBCodes',
 	'ACP_BOARD_CONFIGURATION'	=> 'Configuració del fòrum',
 	'ACP_BOARD_FEATURES'		=> 'Característiques del fòrum',
