@@ -88,9 +88,10 @@ $lang = array_merge($lang, array(
 	'AVATAR_PARTIAL_UPLOAD'			=> 'El fitxer especificat només s’ha carregat parcialment.',
 	'AVATAR_PHP_SIZE_NA'			=> 'La mida del fitxer d’avatar és massa gran.<br />No s’ha pogut determinar la mida màxima permesa definida a php.ini.',
 	'AVATAR_PHP_SIZE_OVERRUN'		=> 'La mida del fitxer d’avatar és massa gran. La mida màxima permesa és de %1$d %2$s.<br />Si us plau, tingueu en compte que això es defineix al fitxer php.ini i no es pot sobreescriure.',
+	'AVATAR_REMOTE_UPLOAD_TIMEOUT'		=> 'No s’ha penjat l’avatar especificat perquè la sol·licitud ha excedit el temps d’espera.',
 	'AVATAR_URL_INVALID'			=> 'L’URL que heu especificat no és vàlida.',
 	'AVATAR_URL_NOT_FOUND'			=> 'No s’ha pogut trobar el fitxer especificat.',
-	'AVATAR_WRONG_FILESIZE'			=> 'El fitxer d’avatar ha de tenir una mida entre 0 i %1d %2s.',
+	'AVATAR_WRONG_FILESIZE'			=> 'El fitxer d’avatar ha de tenir una mida entre 0 i %1$d %2$s.',
 	'AVATAR_WRONG_SIZE'				=> 'L’avatar tramès té %5$d píxels d’amplària i %6$d píxels d’alçària. Els avatars han de tenir com a mínim %1$d píxels d’amplària i %2$d píxels d’alçària, i com a màxim %3$d píxels d’amplària i %4$d píxels d’alçària.',
 
 	'BACK_TO_TOP'			=> 'Torna a l’inici',
@@ -341,6 +342,9 @@ $lang = array_merge($lang, array(
 	'MODERATE'				=> 'Modera',
 	'MODERATOR'				=> 'Moderador',
 	'MODERATORS'			=> 'Moderadors',
+	'MODULE_NOT_ACCESS'		=> 'Mòdul no accessible',
+	'MODULE_NOT_FIND'		=> 'No s’ha trobat el mòdul %s',
+	'MODULE_FILE_INCORRECT_CLASS'	=> 'El fitxer de módul %s no conté una classe correcta [%s]',
 	'MONTH'					=> 'Mes',
 	'MOVE'					=> 'Desplaça',
 	'MSNM'					=> 'MSNM/WLM',
@@ -651,7 +655,7 @@ $lang = array_merge($lang, array(
 	'TOTAL_USERS_ZERO'	=> 'Nombre de membres <strong>0</strong>',
 	'TRACKED_PHP_ERROR'	=> 'Errors del PHP detectats: %s',
 
-	'UNABLE_GET_IMAGE_SIZE'	=> 'No s’han pogut determinar les dimensions de la imatge.',
+	'UNABLE_GET_IMAGE_SIZE'	=> 'No s’han pogut determinar les dimensions de la imatge. Verifiqueu que l’URL que heu proporcionat és correcte.',
 	'UNABLE_TO_DELIVER_FILE'=> 'No s’ha pogut lliurar el fitxer.',
 	'UNKNOWN_BROWSER'		=> 'Navegador desconegut',
 	'UNMARK_ALL'			=> 'Desmarca’ls tots',
